Package: xpectr
Title: Generates Expectations for 'testthat' Unit Testing
Version: 0.4.3
Authors@R: 
    c(person(given = "Ludvig Renbo",
             family = "Olsen",
             role = c("aut", "cre"),
             email = "r-pkgs@ludvigolsen.dk"),
      person(given = "R. Mark",
             family = "Sharp",
             role = c("ctb")))
Description: Helps systematize and ease the process of 
    building unit tests with the 'testthat' package by providing 
    tools for generating expectations.
License: MIT + file LICENSE
URL: https://github.com/ludvigolsen/xpectr
BugReports: https://github.com/ludvigolsen/xpectr/issues
Depends: R (>= 3.5.0)
Imports: clipr (>= 0.7.0), checkmate (>= 2.0.0), dplyr, fansi (>=
        0.4.1), lifecycle, plyr, rlang, rstudioapi (>= 0.10), stats,
        testthat (>= 2.3.1), tibble, utils, withr (>= 2.0.0)
Suggests: data.table, knitr, rmarkdown
RdMacros: lifecycle
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.1
VignetteBuilder: knitr
Author: Ludvig Renbo Olsen [aut, cre],
  R. Mark Sharp [ctb]
Maintainer: Ludvig Renbo Olsen <r-pkgs@ludvigolsen.dk>
Built: R 4.4.0; ; 2024-04-28 00:50:27 UTC; unix
