# Generated by roxygen2: do not edit by hand

export(assertCollectionAddin)
export(capture_parse_eval_side_effects)
export(capture_side_effects)
export(dputSelectedAddin)
export(element_classes)
export(element_lengths)
export(element_types)
export(gxs_function)
export(gxs_selection)
export(initializeGXSFunctionAddin)
export(initializeTestthatAddin)
export(insertExpectationsAddin)
export(insertExpectationsCopyEnvAddin)
export(message_if)
export(navigateTestFileAddin)
export(num_total_elements)
export(prepare_insertion)
export(set_test_seed)
export(simplified_formals)
export(smpl)
export(stop_if)
export(strip)
export(strip_msg)
export(suppress_mw)
export(warn_if)
export(wrapStringAddin)
importFrom(dplyr,"%>%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(stats,runif)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,tail)
